mysql.exceptions.internal.No_More_Results

Package mysql :: Package exceptions :: Module internal :: Class No_More_Results |
[hide private]
[frames] | no frames]

# Class No_More_Results

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              No_More_Results

No more results are available in the mysql.connection.Connection.next_result method.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`